package com.jeremyparsons.imaging;

/**
 * Should be thread safe for a single conventional run but should be careful calling synchronized methods in many many ways.
 * Should use AtomicInteger etc.
 * @author Jeremy D. Parsons
 *
 */
public class CopyModel {
	// Standard defaults 
	public static final boolean DEF_ULTRA_QUAL = false;
	public static final boolean DEF_DEGRAIN = false;
	public static final boolean DEF_BASELINE_ENCODING = true;
	public static final float DEF_QUALITY = 0.8F;
	public static final int DEF_OUT_WIDTH = 1200;
	public static final int DEF_OUT_HEIGHT = 1200;
	public static final int DEF_THREAD_COUNT_ADJUST = 0;

	private boolean desiredBaseline = DEF_BASELINE_ENCODING;
	private boolean desiredDegrain = DEF_DEGRAIN;
	private boolean desiredUltraQual = DEF_ULTRA_QUAL;
	private int desiredWidth = DEF_OUT_WIDTH;
	private int desiredHeight = DEF_OUT_HEIGHT;
	private float desiredQuality = DEF_QUALITY;
	private int desiredThreadsAdjust = DEF_THREAD_COUNT_ADJUST;

	
	private int writtenCount = 0;
	private long writtenSize = 0L;

	public CopyModel() {
	}

	public int getDesiredWidth() {
		return desiredWidth;
	}

	public void setDesiredWidth(int desiredWidth) {
		this.desiredWidth = desiredWidth;
	}

	public int getDesiredHeight() {
		return desiredHeight;
	}

	public void setDesiredHeight(int desiredHeight) {
		this.desiredHeight = desiredHeight;
	}

	public float getDesiredQuality() {
		return desiredQuality;
	}

	public void setDesiredQuality(float desiredQuality) {
		this.desiredQuality = desiredQuality;
	}

	public boolean isDesiredBaseline() {
		return desiredBaseline;
	}

	public void setDesiredBaseline(boolean desiredBaseline) {
		this.desiredBaseline = desiredBaseline;
	}

	public boolean isDesiredDegrain() {
		return desiredDegrain;
	}

	public void setDesiredDegrain(boolean desiredDegrain) {
		this.desiredDegrain = desiredDegrain;
	}

	public boolean isDesiredUltraQual() {
		return desiredUltraQual;
	}

	public void setDesiredUltraQual(boolean desiredUltraQual) {
		this.desiredUltraQual = desiredUltraQual;
	}

	public int getWrittenCount() {
		return writtenCount;
	}

	synchronized public int incWrittenCount() {
		return ++writtenCount;
	}

	public void setWrittenCount(int writtenCount) {
		this.writtenCount = writtenCount;
	}

	public long getWrittenSize() {
		return writtenSize;
	}

	public void setWrittenSize(long writtenSize) {
		this.writtenSize = writtenSize;
	}
	synchronized public void addWrittenSize(long writtenSize) {
		this.writtenSize += writtenSize;
	}

	public void setDesiredThreadCountAdjust(int threadAdjust) {
		this.desiredThreadsAdjust = threadAdjust;
		
	}

	public int getDesiredThreadCountAdjust() {
		return this.desiredThreadsAdjust;
	}

}