package com.jeremyparsons.imaging;

import java.awt.image.BufferedImage;
import java.io.FileOutputStream;
import java.io.File;
import javax.imageio.ImageIO;
import org.imgscalr.Scalr.Method;

public class ResizeRunnable implements Runnable{
	File top;
	File topCopy;
	CopyModel copyModel;
		
	public ResizeRunnable(File top, File topCopy, CopyModel copyModel){
		this.top = top;
		this.topCopy = topCopy;
		this.copyModel = copyModel;
	}
	
	/** Most work is actually done in here calling scaling on each image */
	/** Maybe should copy file modification dates over too ? */
	public void run(){
		BufferedImage inImage = loadImage(top);
		if (inImage == null){
			return; // Nothing to do, don't complain here
		}
		// ColorModel colorModel = inImage.getColorModel();
		// float scaleFactor = getScaleFactor(lastImage, this.desiredWidth, this.desiredHeight);
		Thread.currentThread().setPriority(Thread.MIN_PRIORITY);
		BufferedImage outImage = org.imgscalr.Scalr.resize(inImage, Method.QUALITY, this.copyModel.getDesiredWidth(), this.copyModel.getDesiredHeight(), org.imgscalr.Scalr.OP_ANTIALIAS);
		try	{
			String exifInfo = null;
			FileOutputStream fOutputStream = new FileOutputStream(topCopy);
			ImageUtil.saveAsJPEG(exifInfo, outImage, copyModel.getDesiredQuality(), fOutputStream);
			if (topCopy.exists() && topCopy.isFile()){
				copyModel.addWrittenSize(topCopy.length());
				copyModel.incWrittenCount();
			}
			fOutputStream.close();
		}
		catch (java.io.FileNotFoundException fNotFEx){
			throw new RuntimeException(fNotFEx);
		}
		catch (java.io.IOException iOEx){
			throw new RuntimeException(iOEx);
		}
		finally{
			inImage.flush();
			outImage.flush();
		}
	}
	
	public BufferedImage loadImage(File top) {
		// File is not a directory so could be a JPEG image
		BufferedImage inImage = null;
		try {
			inImage = ImageIO.read(top);
			}
		catch (java.io.IOException iOEx){
			UserComms.warn(iOEx.toString());
			return(null);
			}
		return inImage;
	}
}
